// main.ts
import { createApp } from "vue";
import "@45drives/houston-common-css/src/index.css";
import "@45drives/houston-common-ui/style.css";
import "./style.css";
import { enterNextDirective } from '@45drives/houston-common-ui'
import { server, patchConsoleToFile } from "@45drives/houston-common-lib";
import App from "./App.vue";

patchConsoleToFile();

const aliasStyleToTheme: Record<string, string> = {
    homelab: "theme-homelab",
    professional: "theme-professional",
};

function applyThemeFromAliasStyle(aliasStyle?: string) {
    const normalized = aliasStyle?.toLowerCase() || "";
    const themeClass = aliasStyleToTheme[normalized] || "theme-default";

    document.documentElement.classList.remove(
        "theme-default",
        "theme-homelab",
        "theme-professional"
    );

    document.documentElement.classList.add(themeClass);
}

async function bootstrapApp() {
    try {
        const serverInfoResult = await server.getServerInfo();

        serverInfoResult.match(
            (info) => {
                const aliasStyle = info["Alias Style"];
                applyThemeFromAliasStyle(aliasStyle);
            },
            (error) => {
                console.error("Failed to get server info:", error);
                applyThemeFromAliasStyle(); // fallback to default
            }
        );
    } catch (err) {
        console.error("Unexpected error during theme setup:", err);
        applyThemeFromAliasStyle(); // fallback to default
    }

    const app = createApp(App);
    app.directive('enter-next', enterNextDirective);
    app.mount("#app");
}

bootstrapApp();
